"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.features = void 0;
exports.find = find;
exports.getBrowserScope = getBrowserScope;
exports.getLatestStableBrowsers = getLatestStableBrowsers;
exports.getSupport = getSupport;
exports.isSupported = isSupported;
exports.setBrowserScope = setBrowserScope;
var _lodash = _interopRequireDefault(require("lodash.memoize"));
var _browserslist = _interopRequireDefault(require("browserslist"));
var _caniuseLite = require("caniuse-lite");
var _utils = require("./utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
var featuresList = Object.keys(_caniuseLite.features);
exports.features = featuresList;
var browsers;
function setBrowserScope(browserList) {
  browsers = (0, _utils.cleanBrowsersList)(browserList);
}
function getBrowserScope() {
  return browsers;
}
var parse = (0, _lodash["default"])(_utils.parseCaniuseData, function (feat, browsers) {
  return feat.title + browsers;
});
function getSupport(query) {
  var feature;
  try {
    feature = (0, _caniuseLite.feature)(_caniuseLite.features[query]);
  } catch (e) {
    var res = find(query);
    if (res.length === 1) return getSupport(res[0]);
    throw new ReferenceError("Please provide a proper feature name. Cannot find ".concat(query));
  }
  return parse(feature, browsers);
}
function isSupported(feature, browsers) {
  var data;
  try {
    data = (0, _caniuseLite.feature)(_caniuseLite.features[feature]);
  } catch (e) {
    var res = find(feature);
    if (res.length === 1) {
      data = _caniuseLite.features[res[0]];
    } else {
      throw new ReferenceError("Please provide a proper feature name. Cannot find ".concat(feature));
    }
  }
  return (0, _browserslist["default"])(browsers, {
    ignoreUnknownVersions: true
  }).map(function (browser) {
    return browser.split(" ");
  }).every(function (browser) {
    return data.stats[browser[0]] && data.stats[browser[0]][browser[1]] === "y";
  });
}
function find(query) {
  if (typeof query !== "string") {
    throw new TypeError("The `query` parameter should be a string.");
  }
  if (~featuresList.indexOf(query)) {
    // exact match
    return query;
  }
  return featuresList.filter(function (file) {
    return (0, _utils.contains)(file, query);
  });
}
function getLatestStableBrowsers() {
  return (0, _browserslist["default"])("last 1 version");
}
setBrowserScope();